@@ -111,11 +111,12 @@ class googleRoutesearchDownloader(Thread):
         self.zoom_min = z_min
         self.zoom_max = z_max
 
-    def parseXml(self, xml_res):
+    def parseXml(self, xml_res, lang = "en"):
         doc = xml.dom.minidom.parseString(xml_res)
 
         step_count = 0
-        self.geonames.points = []
+        if lang == "en":
+            self.geonames.points = []
 
         download_offline = 0
         if self.offline:
@@ -138,85 +139,107 @@ class googleRoutesearchDownloader(Thread):
             str = str.replace("  ", " ")
             ico = None
             ico_name = None
+            if lang == "en":
 
-            if str.find("Continue straight") == 0:
-                ico_name = "./plugins/ico_turn_32_32.png"
-                ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Turn left") == 0 or str.find("Take the 1st left") == 0 or str.find("Take the 2nd left") == 0 or str.find("Take the 3rd left") == 0:
-                ico_name = "./plugins/ico_turn_left_32_32.png"
-                ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Turn right") == 0 or str.find("Take the 1st right") == 0 or str.find("Take the 2nd right") == 0 or str.find("Take the 3rd right") == 0:
-                ico_name = "./plugins/ico_turn_right_32_32.png"
-                ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Slight right") == 0:
-                ico_name = "./plugins/ico_turn_sright_32_32.png"
-                ico = gdk.pixbuf_new_from_file(ico_name)
-            elif str.find("Slight left") == 0:
-                ico_name = "./plugins/ico_turn_sleft_32_32.png"
-                ico = gdk.pixbuf_new_from_file( ico_name)
-            elif str.find("Keep left") == 0:
-                ico_name = "./plugins/ico_turn_keep_left_32_32.png"
-                ico = gdk.pixbuf_new_from_file( ico_name)
-            elif str.find("Keep right") == 0:
-                ico_name = "./plugins/ico_turn_keep_right_32_32.png"
-                ico = gdk.pixbuf_new_from_file( ico_name)
-            elif str.find("Make a U-turn") == 0 or str.find("Sharp left") == 0 or str.find("Sharp right") == 0:
-                ico_name = "./plugins/ico_turn_u_32_32.png"
-                ico = gdk.pixbuf_new_from_file( ico_name)
-            self.geonames.markers.append([
-                                 float(sll[0]),float(sll[1]),
-                                 str,
-                                 ico,
-                                 ico_name
-                                 ])
+                if str.find("Continue straight") == 0:
+                    ico_name = "./plugins/ico_turn_32_32.png"
+                    ico = gdk.pixbuf_new_from_file(ico_name)
+                elif str.find("Turn left") == 0 or str.find("Take the 1st left") == 0 or str.find("Take the 2nd left") == 0 or str.find("Take the 3rd left") == 0:
+                    ico_name = "./plugins/ico_turn_left_32_32.png"
+                    ico = gdk.pixbuf_new_from_file(ico_name)
+                elif str.find("Turn right") == 0 or str.find("Take the 1st right") == 0 or str.find("Take the 2nd right") == 0 or str.find("Take the 3rd right") == 0:
+                    ico_name = "./plugins/ico_turn_right_32_32.png"
+                    ico = gdk.pixbuf_new_from_file(ico_name)
+                elif str.find("Slight right") == 0:
+                    ico_name = "./plugins/ico_turn_sright_32_32.png"
+                    ico = gdk.pixbuf_new_from_file(ico_name)
+                elif str.find("Slight left") == 0:
+                    ico_name = "./plugins/ico_turn_sleft_32_32.png"
+                    ico = gdk.pixbuf_new_from_file( ico_name)
+                elif str.find("Keep left") == 0:
+                    ico_name = "./plugins/ico_turn_keep_left_32_32.png"
+                    ico = gdk.pixbuf_new_from_file( ico_name)
+                elif str.find("Keep right") == 0:
+                    ico_name = "./plugins/ico_turn_keep_right_32_32.png"
+                    ico = gdk.pixbuf_new_from_file( ico_name)
+                elif str.find("Make a U-turn") == 0 or str.find("Sharp left") == 0 or str.find("Sharp right") == 0:
+                    ico_name = "./plugins/ico_turn_u_32_32.png"
+                    ico = gdk.pixbuf_new_from_file( ico_name)
+                self.geonames.markers.append([
+                                     float(sll[0]),float(sll[1]),
+                                     str,
+                                     ico,
+                                     ico_name
+                                     ])
+                t = osmgpsmap.GpsMapTrack()
+                t.props.color = gtk.gdk.color_parse("#1a39fb")
 
-            t = osmgpsmap.GpsMapTrack()
-            t.props.color = gtk.gdk.color_parse("#1a39fb")
+                self.geonames.tracks.append( t )
+                point0 = osmgpsmap.point_new_degrees(float(sll[0]),float(sll[1]))
+                point1 = osmgpsmap.point_new_degrees(float(ell[0]),float(ell[1]))
+                t.add_point( point0 )
+                self.geonames.points.append( [float(sll[0]),float(sll[1])] )
 
-            self.geonames.tracks.append( t )
-            point0 = osmgpsmap.point_new_degrees(float(sll[0]),float(sll[1]))
-            point1 = osmgpsmap.point_new_degrees(float(ell[0]),float(ell[1]))
-            t.add_point( point0 )
-            self.geonames.points.append( [float(sll[0]),float(sll[1])] )
+                points = step.getElementsByTagName("points")[0].childNodes[0].data
+                if len(points) > 2:
+                    a = decode_line( points )
+                    print "points from points in poliline", len( a )
+                    for p in a:
+                        point0 = osmgpsmap.point_new_degrees(float(p[0]),float(p[1]))
+                        self.geonames.points.append( [float(p[0]),float(p[1])] )
+                        t.add_point( point0 )
 
+                        if download_offline:
+                            self.osmMapa.osm.download_maps(
+                                   float(p[0]),float(p[1]),
+                                   float(p[0]),float(p[1]),
+                                   self.zoom_min,self.zoom_max
+                                   )
 
+                t.add_point( point1 )
+                self.geonames.points.append( [float(ell[0]),float(ell[1])] )
+                self.osmMapa.osm.track_add( t )
 
-            points = step.getElementsByTagName("points")[0].childNodes[0].data
-            if len(points) > 2:
-                a = decode_line( points )
-                print "points from points in poliline", len( a )
-                for p in a:
-                    point0 = osmgpsmap.point_new_degrees(float(p[0]),float(p[1]))
-                    self.geonames.points.append( [float(p[0]),float(p[1])] )
-                    t.add_point( point0 )
+                if step_count == 0:
+                    i = gdk.pixbuf_new_from_file("./plugins/ico_comment_g.png")
+                    self.geonames.icons.append( self.osmMapa.osm.image_add( float(sll[0]),float(sll[1]), i ) )
 
-                    if download_offline:
-                        self.osmMapa.osm.download_maps(
-                               float(p[0]),float(p[1]),
-                               float(p[0]),float(p[1]),
-                               self.zoom_min,self.zoom_max
-                               )
+            else:
+                m = self.geonames.markers[ len(self.geonames.markers_lang) ]
+                self.geonames.markers_lang.append([
+                                     m[0],m[1],
+                                     str,
+                                     m[3],
+                                     m[4]
+                                    ])
 
 
-
-            t.add_point( point1 )
-            self.geonames.points.append( [float(ell[0]),float(ell[1])] )
-            self.osmMapa.osm.track_add( t )
-
-            if step_count == 0:
-                i = gdk.pixbuf_new_from_file("./plugins/ico_comment_g.png")
-                self.geonames.icons.append( self.osmMapa.osm.image_add( float(sll[0]),float(sll[1]), i ) )
-
             step_count+=1
 
+
+
+
+
+
         if step_count > 0:
             ico = gdk.pixbuf_new_from_file("./plugins/ico_comment_m.png")
-            self.geonames.markers.append([
-                 float(ell[0]),float(ell[1]),
-                 "Destination point",
-                 ico,
-                 "./plugins/ico_comment_m.png"
-                 ])
+            if lang == "en":
+                str = "Destination point"
+                self.geonames.markers.append([
+                    float(ell[0]),float(ell[1]),
+                    str,
+                    ico,
+                    "./plugins/ico_comment_m.png"
+                    ])
+            else:
+                str = "DONE"
+                self.geonames.markers_lang.append([
+                     float(ell[0]),float(ell[1]),
+                     str,
+                     ico,
+                     "./plugins/ico_comment_m.png"
+                     ])
+
 
         print "step added ", step_count
 
@@ -226,7 +249,7 @@ class googleRoutesearchDownloader(Thread):
 
 
 
-    def downloadXml(self):
+    def downloadXml(self, lang = "en"):
         """
         maps.googleapis.com/maps/api/directions/xml?&destination=Polska,Pozna%C5%84,os.Stare%20%C5%BBegrze&waypoints=Polska,Pozna%C5%84,ul.%20g%C5%82ogowska%2010&sensor=false
         """
@@ -241,7 +264,7 @@ class googleRoutesearchDownloader(Thread):
             lat, lon = self.osmMapa.get_may_current_ll()
             end = "loc:%f+%f"%( float(lat), float(lon)  )
 
-        req = "/maps/api/directions/xml?mode=%s&origin=%s&destination=%s&sensor=true&language=en" % (self.geonames.mode[self.CONFIG['google_routesearch_mode']],start,end)
+        req = "/maps/api/directions/xml?mode=%s&origin=%s&destination=%s&sensor=true&language=%s" % (self.geonames.mode[self.CONFIG['google_routesearch_mode']],start,end, lang)
         print req
         req = req.replace(" ", "%20")
         conn.request("GET", req)
@@ -255,6 +278,13 @@ class googleRoutesearchDownloader(Thread):
         print "googleRoutesearchDownloader parse"
         self.parseXml( res )
 
+        if self.CONFIG['google_routesearch_speak_street_lang'] == "en":
+            self.geonames.markers_lang = self.geonames.markers
+        else:
+            self.geonames.osmMapa.showBanner("downloading lang pack...")
+            res2 = self.downloadXml(self.CONFIG['google_routesearch_speak_street_lang'])
+            self.parseXml( res2, self.CONFIG['google_routesearch_speak_street_lang'] )
+
 
 class SaveTrackDialog( hildon.Program):
     def __init__(self, zoom=0, lat=0, lon=0):
@@ -292,6 +322,7 @@ class google_routesearch:
         self.tracks_on_map = []
         self.points = []
         self.markers = []
+        self.markers_lang = []
         self.markers_icons = []
 
         self.icons = []
@@ -376,6 +407,7 @@ class google_routesearch:
         print "---- google_routesearch espeak ----"
         print "---- speak [%s] ----" % str
 
+        """
         if str.find( " onto " ) <> -1:
             tmp = []
             tmp = str.split("onto")
@@ -389,9 +421,11 @@ class google_routesearch:
             tmp = str.split(" to stay on ")
             cmd = "espeak \"%s to stay on\" && espeak -v %s \"%s\" &" %( tmp[0],self.CONFIG['google_routesearch_speak_street_lang'], tmp[1])
         else:
-            cmd = "espeak \"%s\""%( str)
+             cmd = "espeak \"%s\""%( str)
+        """
+        cmd = "espeak -v %s \"%s\""%( self.CONFIG['google_routesearch_speak_street_lang'], str)
 
-        print "[[[%s]]]"%cmd
+        #print "[[[%s]]]"%cmd
         #return None
         os.system( cmd )
 
@@ -445,7 +479,7 @@ class google_routesearch:
 
                 cr = gdkdrawable.cairo_create()
 
-                for p in self.markers:
+                for p in self.markers_lang:
                     lt = p[0]
                     ln = p[1]
                     #print "lt:",t_lt,t_ln,"\t c:",lt,ln,"\tb:",b_lt,b_ln
@@ -498,61 +532,6 @@ class google_routesearch:
 
 
 
-            """
-            for i,p in enumerate(self.points):
-                if i == 0:
-                    p_old = p
-                else:
-                    dis = self.dist_from_vector( [p[0],p[1]], [latc,lonc],[p_old[0],p_old[1]] )
-                    if dis_min == -10:
-                        dis_min = dis
-                        id_next = i
-
-                    elif dis_min>=dis:
-                        dis_min = dis
-                        id_next = i
-
-                        print "dis_min:[", dis_min,"] id:[",i,"]"
-                    p_old = p
-
-            for p in self.points:
-                dis = self.osmMapa.distance( p[0],p[1], latc, lonc )
-                if dis_min == -10:
-                    dis_min = dis
-                    id_next = id
-
-                elif dis_min>=dis:
-                    dis_min = dis
-                    id_next = id
-
-                    #print "dis_min:[", dis_min,"] id:[",id,"]"
-                id+=1
-
-            #print "next point id:[",id_next,"]"
-            # chk id_next is forword or backword
-            try:
-                p0 = self.points[id_next]
-                p1 = self.points[id_next+1]
-
-                dis_p0_pc = self.osmMapa.distance( p0[0],p0[1], latc, lonc )
-                dis_p1_pc = self.osmMapa.distance( p1[0],p1[1], latc, lonc )
-                dis_p1_p0 = self.osmMapa.distance( p1[0],p1[1], p0[0], p0[1] )
-                #print "p0_pc[",dis_p0_pc,"] p1_pc[",dis_p1_pc,"] p1_p0[",dis_p1_p0,"]"
-                if dis_p0_pc <  dis_p1_pc and dis_p1_p0>dis_p1_pc:
-                    id_next+=1
-                    #print "search for close point correct"
-            except:
-                print "search for close point correct ERROR"
-            #print "next point id:[",id_next,"]"
-            #p = self.points[id_next]
-            #x,y = self.osmMapa.osm.geographic_to_screen(p[0],p[1])
-            #self.osmMapa.draw_cloud( cr, x,y, ("clost point:\ndist:%f\n[%f,%f]"%(dis_min,p[0],p[1])) )
-            """
-
-            #id_next-=1
-            # next key turn
-            #print "search for next key turn, close point:[",id_next,"]"
-
             search_for_it = -1
             for i in range(id_next, len(self.points)):
                 p = self.points[i]
@@ -561,7 +540,7 @@ class google_routesearch:
                 #self.osmMapa.draw_cloud( cr, x,y, ("id:[%i]\n[%f,%f]"%(i,p[0],p[1])) )
 
                 id = 0
-                for m in self.markers:
+                for m in self.markers_lang:
                     #print "marker:[",m,"] p[",p,"]"
                     if m[0] == p[0] and m[1] == p[1]:
                         search_for_it = id
@@ -578,7 +557,7 @@ class google_routesearch:
                         t = int( time.strftime("%Y%m%d%H%M%S", time.localtime() ) )
 
 
-                        info = "in: %s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
+                        info = "%s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
                         self.osmMapa.draw_cloud( cr, 50,5, info, 20, False)
 
                         dist = "track: %s / %s " % (self.osmMapa.distance_to_string(dis_done), self.osmMapa.distance_to_string(dis_total) )
@@ -596,7 +575,7 @@ class google_routesearch:
                             self.espeak_dis = 0.203
                             self.espeak_time = t+5
 
-                            speak = "in %s %s " % ( self.osmMapa.distance_to_string(dis_to_key).replace("m","meters").replace("km", "kilometers"),  m[2])
+                            speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
                             self.espeak_cmd( speak )
                         elif self.espeak_say == m[2] and t > (self.espeak_time):
                                 #print dis_to_key,"\t",self.espeak_dis,"\t",t
@@ -605,20 +584,20 @@ class google_routesearch:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+4
 
-                                    speak = "in %s %s " % ( self.osmMapa.distance_to_string(dis_to_key).replace("m","meters").replace("km", "kilometers"),  m[2])
+                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
                                     self.espeak_cmd( speak )
 
                                 elif dis_to_key < 0.100 and self.espeak_dis > 0.100:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+4
 
-                                    speak = "in %s %s " % ( self.osmMapa.distance_to_string(dis_to_key).replace("m","meters").replace("km", "kilometers"),  m[2])
+                                    speak = "%s. %s" % ( self.osmMapa.distance_to_string(dis_to_key),  m[2])
                                     self.espeak_cmd( speak )
                                 elif dis_to_key < 0.025 and self.espeak_dis > 0:
                                     self.espeak_dis = dis_to_key
                                     self.espeak_time = t+30
 
-                                    speak = "%s " % ( m[2])
+                                    speak = "%s" % ( m[2])
                                     self.espeak_cmd( speak )
 
 
@@ -659,6 +638,7 @@ class google_routesearch:
         self.icons = []
 
         self.markers = []
+        self.markers_lang = []
         self.my_point = -1
 
     def on_clear(self, w, dialog):
@@ -728,11 +708,16 @@ class google_routesearch:
                 iter+=1
         print "selected mode: ", self.mode[id]
         self.CONFIG['google_routesearch_mode'] = id
-    def on_changed_lang (self,picker):
+    def on_changed_lang (self,picker,dialog):
         str = picker.get_value()
         for i, lang_name in enumerate(self.espeak_langs):
             if lang_name == str:
-                self.CONFIG['google_routesearch_speak_street_lang'] = str
+                if str <> self.CONFIG['google_routesearch_speak_street_lang'] and len(self.points)>0:
+                    self.CONFIG['google_routesearch_speak_street_lang'] = str
+                    self.search_action(dialog)
+
+                else:
+                    self.CONFIG['google_routesearch_speak_street_lang'] = str
                 break
 
         print "selected lang: ", self.CONFIG['google_routesearch_speak_street_lang']
@@ -749,7 +734,7 @@ class google_routesearch:
             f.write("""<?xml version="1.0"?>
 <gpx creator="yosmapa" version="1.0">""" )
 
-            for p in self.markers:
+            for p in self.markers_lang:
                 f.write("""
 <wpt lat="%f" lon="%f">
   <name>%s</name>
@@ -829,7 +814,7 @@ class google_routesearch:
                     id = i
             pb_lang.set_selector(selector_lang)
             pb_lang.set_active( id  )
-            pb_lang.connect("value-changed",self.on_changed_lang)
+            pb_lang.connect("value-changed",self.on_changed_lang, dialog)
             hbox.pack_start( pb_lang, True )
 
 
