@@ -63,7 +63,9 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
-0.19
+0.19-2
+    plugin[google_routesearch] full multi lang support
+0.19-1
     config store except broken file
         no more config versioning
     new search engin :) one for all :)
